@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""WRAPPERS
+"""WRAPPERS.
 
 This module contains wrappers for adding additional features to functions
 
@@ -8,23 +8,19 @@ This module contains wrappers for adding additional features to functions
 
 """
 
-from sys import version_info
 from functools import wraps
-if version_info[0] < 3:  # pragma: no cover
-    from inspect import getargspec as argspec
-else:
-    from inspect import getfullargspec as argspec
+from inspect import getfullargspec as argspec
 
 
 def add_args_kwargs(func):
-    """Add Args and Kwargs
+    """Add Args and Kwargs.
 
     This wrapper adds support for additional arguments and keyword arguments to
     any callable function.
 
     Parameters
     ----------
-    func : function
+    func : callable
         Callable function
 
     Returns
@@ -33,7 +29,6 @@ def add_args_kwargs(func):
         wrapper
 
     """
-
     @wraps(func)
     def wrapper(*args, **kwargs):
 
@@ -41,16 +36,14 @@ def add_args_kwargs(func):
 
         # if 'args' not in props:
         if isinstance(props[1], type(None)):
-
             args = args[:len(props[0])]
 
-        if ((not isinstance(props[2], type(None))) or
-                (not isinstance(props[3], type(None)))):
-
+        if (
+            (not isinstance(props[2], type(None)))
+            or (not isinstance(props[3], type(None)))
+        ):
             return func(*args, **kwargs)
 
-        else:
-
-            return func(*args)
+        return func(*args)
 
     return wrapper
